==> haskell-pipes-http-1.0.6-374-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pipes-http
version:              1.0.6
visibility:           public
id:                   pipes-http-1.0.6-ACi1OIHEgtbBNuq7hpR0yN
key:                  pipes-http-1.0.6-ACi1OIHEgtbBNuq7hpR0yN
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library

category:             Pipes, Web
abi:                  96f1106646889c4a9bfb7421ef410021
exposed:              True
exposed-modules:      Pipes.HTTP
import-dirs:          /usr/lib/ghc-9.0.1/site-local/pipes-http-1.0.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/pipes-http-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/pipes-http-1.0.6
hs-libraries:         HSpipes-http-1.0.6-ACi1OIHEgtbBNuq7hpR0yN
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    http-client-0.7.9-4QDsAMxj7sz7yGu8kHH5hl
    http-client-tls-0.3.5.3-F45mVQUUOVqKNVzgg1kWEu
    pipes-4.3.16-5XKWwDwpDLzGLxIjXlyVqa

haddock-interfaces:   /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html:         /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-http-1.0.6-375-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pipes-http
version:              1.0.6
visibility:           public
id:                   pipes-http-1.0.6-4XnIoSorrEiDIbqDkvGHBv
key:                  pipes-http-1.0.6-4XnIoSorrEiDIbqDkvGHBv
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library

category:             Pipes, Web
abi:                  9326df09caeb332e173cbbef8cb607f1
exposed:              True
exposed-modules:      Pipes.HTTP
import-dirs:          /usr/lib/ghc-9.0.1/site-local/pipes-http-1.0.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/pipes-http-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/pipes-http-1.0.6
hs-libraries:         HSpipes-http-1.0.6-4XnIoSorrEiDIbqDkvGHBv
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    http-client-0.7.9-4QDsAMxj7sz7yGu8kHH5hl
    http-client-tls-0.3.5.3-DAvN9t19CC2CY6pSl8H9nS
    pipes-4.3.16-5XKWwDwpDLzGLxIjXlyVqa

haddock-interfaces:   /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html:         /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
